@@ -1,11 +1,11 @@
 __all__ = ("VERSION")
 
+__version__ = '1.8.4'
 name = "stackify-python-apm"
 
-try:
-    VERSION = __import__("pkg_resources").get_distribution("stackifyapm").version
-except Exception:
-    VERSION = None
+
+VERSION = __version__
+
 
 from stackifyapm.base import Client  # noqa
 from stackifyapm.conf import setup_logging  # noqa
